PyDPF
======

.. image:: https://img.shields.io/pypi/v/pydpf
   :target: https://pypi.org/project/pydpf/
   :alt: PyPI version

.. image:: https://img.shields.io/badge/python-3.12%2B-blue
   :target: https://pypi.org/project/pydpf/
   :alt: Python versions

.. image:: https://img.shields.io/badge/docs-online-green
   :target: https://python-dpf.readthedocs.io/en/latest/
   :alt: Docs

.. image:: https://img.shields.io/badge/github-repo-blue?logo=github
   :target:  https://github.com/John-JoB/pydpf
   :alt: GitHub

PyDPF is an extensible package for differentiable particle filtering. Designed for researchers and practitioners working with
deep sequential Monte Carlo methods.

See the full documentation at:
https://python-dpf.readthedocs.io/en/latest/index.html

Check out our getting started tutorial at:
https://python-dpf.readthedocs.io/en/latest/tutorial.html

If you use this package in your publication please cite our paper:

.. code-block:: text

    @article{brady2025pydpf,
          title={PyDPF: A Python Package for Differentiable Particle Filtering},
          author={John-Joseph Brady and Benjamin Cox and Yunpeng Li and V\'{i}ctor Elvira},
          year={2025},
          journal={arXiv preprint arXiv:2510.25693},
          url={https://arxiv.org/abs/2510.25693},
    }